@@ -19,9 +19,11 @@ from .Violin import Violin
 from .Base import Base
 from .CategoryLookup import CategoryLookup
 from .CombinecatTransform import CombinecatTransform
+from .DropnaTransform import DropnaTransform
 from .EvalTransform import EvalTransform
 from .MeltTransform import MeltTransform
 from .SubComponentBase import SubComponentBase
+from .WideToLong import WideToLong
 
 __all__ = [
     "Configurator",
@@ -45,7 +47,9 @@ __all__ = [
     "Base",
     "CategoryLookup",
     "CombinecatTransform",
+    "DropnaTransform",
     "EvalTransform",
     "MeltTransform",
-    "SubComponentBase"
+    "SubComponentBase",
+    "WideToLong"
 ]
\ No newline at end of file
