@@ -2,3 +2,5 @@ from . import _eval as eval
 from . import _combinecat  as combinecat
 from . import _melt as melt 
 from . import _catlookup as catlookup
+from . import _dropna as dropna
+from . import _wide_to_long as wide_to_long
